pub struct JsLayoutMetrics {
pub offset_left: f64,
pub offset_top: f64,
pub offset_width: f64,
pub offset_height: f64,
pub client_width: f64,
pub client_height: f64,
pub rect_left: f64,
pub rect_top: f64,
pub rect_width: f64,
pub rect_height: f64,
}Expand description
Geometry produced by the committed layout tree for a live DOM element.
Fields
offset_left: f64offset_top: f64offset_width: f64offset_height: f64client_width: f64client_height: f64rect_left: f64rect_top: f64rect_width: f64rect_height: f64Trait Implementations
Sourceimpl Clone for JsLayoutMetrics
impl Clone for JsLayoutMetrics
Sourcefn clone(&self) -> JsLayoutMetrics
fn clone(&self) -> JsLayoutMetrics
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for JsLayoutMetrics
Sourceimpl Debug for JsLayoutMetrics
impl Debug for JsLayoutMetrics
Sourceimpl Default for JsLayoutMetrics
impl Default for JsLayoutMetrics
Sourcefn default() -> JsLayoutMetrics
fn default() -> JsLayoutMetrics
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for JsLayoutMetrics
impl PartialEq for JsLayoutMetrics
Sourcefn eq(&self, other: &JsLayoutMetrics) -> bool
fn eq(&self, other: &JsLayoutMetrics) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for JsLayoutMetrics